import { useEffect, useRef, useState } from "react";
import { userLogin } from "../../api";
import { Message, Button } from "@arco-design/web-react";
import "./index.less";

const defaultForm = {
  user_login: "",
  user_pass: "",
};

type TLoginMethod = "useQRCode" | "useSms";

const DURATION = 3; // 验证码倒计时

export function Login() {
  const [smsLoginForm, setSmsLoginForm] = useState(defaultForm);
  const [loginMethod, setLoginMethod] = useState<TLoginMethod>("useSms");
  let [countdown, setCountdown] = useState(DURATION);
  const timer = useRef<any>();

  const onClickSmsBtn = () => {
    setTimeout(() => {
      Message.success("验证码已发送");
      timer.current = setInterval(() => setCountdown(countdown--), 1000);
    }, 500);
  };

  const onClickSmsLogin = () => {
    userLogin(smsLoginForm).then((res: any) => {
      const { code, data, msg } = res;
      if (code === 10000) {
        Message.success(msg);
        console.log(data);
      }
      if (code === 20000) Message.error(msg);
    });
  };

  useEffect(() => {
    if (countdown === 0) {
      clearInterval(timer.current);
      setCountdown(DURATION);
    }
  }, [countdown]);

  return (
    <div className="container" style={{ textAlign: "center", paddingTop: 100 }}>
      <div style={{ width: 350, display: "inline-block" }}>
        <div className="form">
          <input
            type="text"
            className="input"
            placeholder="手机"
            onChange={(e) =>
              setSmsLoginForm((p) => ({
                ...p,
                user_login: e.target.value,
              }))
            }
          />
          <div className="sms-group">
            <input
              className="input"
              type="text"
              onChange={(e) =>
                setSmsLoginForm((p) => ({
                  ...p,
                  user_pass: e.target.value,
                }))
              }
              placeholder="验证码"
            ></input>
            <Button type="text" onClick={onClickSmsBtn}>
              {countdown === DURATION ? "获取" : countdown + "s"}
            </Button>
          </div>
        </div>
        <button className="submit-btn" onClick={onClickSmsLogin}>
          登录
        </button>
      </div>
    </div>
  );
}
